# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

sys.path.insert(0, os.path.abspath("../.."))

"""
Sphinx documentation builder
"""

import os

project = "LabOne Q Software"
copyright = "2020, Zurich Instruments AG - All Rights Reserved."  # pylint: disable=redefined-builtin
author = "Zurich Instruments LabOne Q Software Development Team"

version = ""
# The full version, including alpha/beta/rc tags
VERSION_FILE_PATH = os.environ.get("VERSION_FILE_PATH")
if VERSION_FILE_PATH:
    with open("../../" + VERSION_FILE_PATH, "r") as f:
        version = f.read()
else:
    version = "development"

release = version

# -- General configuration ---------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.napoleon",
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    "sphinx.ext.mathjax",
    "sphinx.ext.viewcode",
    "sphinx.ext.extlinks",
]
html_static_path = ["_static"]
templates_path = ["_templates"]
html_css_files = [
    "style.css",
]

# -----------------------------------------------------------------------------
# Autosummary
# -----------------------------------------------------------------------------

autosummary_generate = False

# -----------------------------------------------------------------------------
# Autodoc
# -----------------------------------------------------------------------------

autodoc_default_options = {
    "inherited-members": None,
}

autodoc_type_aliases = {
    "ArrayLike": "ArrayLike",
    "Union[ArrayLike, Pulse]": "Union[ArrayLike, Pulse]",
}

autodoc_typehints = "signature"

autoclass_content = "both"


# If true, figures, tables and code-blocks are automatically numbered if they
# have a caption.
numfig = True

# A dictionary mapping 'figure', 'table', 'code-block' and 'section' to
# strings that are used for format of figure numbers. As a special character,
# %s will be replaced to figure number.
numfig_format = {"table": "Table %s"}

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = [
    "apidocs/*compiler*",
    "apidocs/*controller*",
    "apidocs/*api*",
    "apidocs/*adapter_dsl_2*",
    "apidocs/*laboneq_facade*",
    "apidocs/*dsl.common*",
    "apidocs/*dsl.result.acquire",
    "apidocs/*dsl.result.compiled",
]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "colorful"

# A boolean that decides whether module names are prepended to all object names
# (for object types where a “module” of some kind is defined), e.g. for
# py:function directives.
add_module_names = False

# A list of prefixes that are ignored for sorting the Python module index
# (e.g., if this is set to ['foo.'], then foo.bar is shown under B, not F).
# This can be handy if you document a project that consists of a single
# package. Works only for the HTML builder currently.
modindex_common_prefix = ["laboneq."]

# -- Configuration for extlinks extension ------------------------------------
# Refer to https://www.sphinx-doc.org/en/master/usage/extensions/extlinks.html


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "pydata_sphinx_theme"

html_logo = "images/logo.png"
# html_sidebars = {'**': ['globaltoc.html']}
html_last_updated_fmt = "%Y/%m/%d"
